Stan Math Library: Class Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

- All
- Functions
- Variables
- Typedefs
- Enumerator
- Related Functions

- _
- a
- b
- c
- d
- e
- f
- g
- h
- i
- j
- l
- m
- n
- o
- p
- q
- r
- s
- t
- v
- w
- x
- y
- ~

Here is a list of all class members with links to the classes they belong to:

### - p -

- partials_ : stan::math::stored_gradient_vari
- precomp_v_vari() : stan::math::precomp_v_vari
- precomp_vv_vari() : stan::math::precomp_vv_vari
- precomp_vvv_vari() : stan::math::precomp_vvv_vari
- precomputed_gradients_vari() : stan::math::precomputed_gradients_vari
- promote() : stan::math::promoter< F, T > , stan::math::promoter< Eigen::Matrix< F, R, C >, Eigen::Matrix< T, R, C > > , stan::math::promoter< Eigen::Matrix< T, R, C >, Eigen::Matrix< T, R, C > > , stan::math::promoter< std::vector< F >, std::vector< T > > , stan::math::promoter< std::vector< T >, std::vector< T > > , stan::math::promoter< T, T >
- promote_to() : stan::math::promoter< F, T > , stan::math::promoter< Eigen::Matrix< F, R, C >, Eigen::Matrix< T, R, C > > , stan::math::promoter< Eigen::Matrix< T, R, C >, Eigen::Matrix< T, R, C > > , stan::math::promoter< std::vector< F >, std::vector< T > > , stan::math::promoter< std::vector< T >, std::vector< T > > , stan::math::promoter< T, T >

[ Stan Home Page ] © 2011–2016, Stan Development Team.